@@ -1,5 +1,5 @@
 /**
- * Copyright © 2017-2025 Wellington Wallace
+ * Copyright © 2017-2026 Wellington Wallace
  *
  * This file is part of Easy Effects
  *
@@ -26,6 +26,7 @@
 #include <cmath>
 #include <cstring>
 #include <format>
+#include <mutex>
 #include <numbers>
 #include <vector>
 #include "util.hpp"
@@ -114,6 +115,8 @@ auto ConvolverKernelFFT::apply_hanning_window(std::vector<float>& signal) -> voi
 }
 
 auto ConvolverKernelFFT::compute_fft_magnitude(std::vector<float>& kernel) -> std::vector<double> {
+  std::scoped_lock<std::mutex> lock(util::fftw_lock());
+
   if (kernel.empty() || kernel.size() < 2) {
     return {};
   }
@@ -181,4 +184,4 @@ auto ConvolverKernelFFT::normalize_spectrum(std::vector<double>& spectrum) -> vo
       value = (value - min_val) / (max_val - min_val);
     }
   }
-}
\ No newline at end of file
+}
