@@ -1,5 +1,5 @@
 /**
- * Copyright © 2017-2025 Wellington Wallace
+ * Copyright © 2017-2026 Wellington Wallace
  *
  * This file is part of Easy Effects.
  *
@@ -23,6 +23,8 @@
 #include <ksharedconfig.h>
 #include <qobject.h>
 #include <qtmetamacros.h>
+#include <QJSEngine>
+#include <QQmlEngine>
 #include <QString>
 
 class KConfigBaseEE : public KConfigSkeleton {
