@@ -1,5 +1,5 @@
 /**
- * Copyright © 2017-2025 Wellington Wallace
+ * Copyright © 2017-2026 Wellington Wallace
  *
  * This file is part of Easy Effects.
  *
@@ -41,8 +41,8 @@ namespace presets {
 
 AutoloadManager::AutoloadManager(DirectoryManager& directory_manager)
     : dir_manager(directory_manager),
-      input_model(new ListModel(this, ListModel::ModelType::Autoloading)),
-      output_model(new ListModel(this, ListModel::ModelType::Autoloading)) {
+      input_model(new ListModel(this, ListModel::ModelType::Autoload)),
+      output_model(new ListModel(this, ListModel::ModelType::Autoload)) {
   refreshListModels();
   prepareFilesystemWatchers();
 }
@@ -60,15 +60,15 @@ void AutoloadManager::prepareFilesystemWatchers() {
   output_watcher.addPath(QString::fromStdString(dir_manager.autoloadOutputDir().string()));
 
   connect(&input_watcher, &QFileSystemWatcher::directoryChanged,
-          [&]() { input_model->update(dir_manager.getAutoloadingProfilesPaths(PipelineType::input)); });
+          [&]() { input_model->update(dir_manager.getAutoloadProfilesPaths(PipelineType::input)); });
 
   connect(&output_watcher, &QFileSystemWatcher::directoryChanged,
-          [&]() { output_model->update(dir_manager.getAutoloadingProfilesPaths(PipelineType::output)); });
+          [&]() { output_model->update(dir_manager.getAutoloadProfilesPaths(PipelineType::output)); });
 }
 
 void AutoloadManager::refreshListModels() {
-  input_model->update(dir_manager.getAutoloadingProfilesPaths(PipelineType::input));
-  output_model->update(dir_manager.getAutoloadingProfilesPaths(PipelineType::output));
+  input_model->update(dir_manager.getAutoloadProfilesPaths(PipelineType::input));
+  output_model->update(dir_manager.getAutoloadProfilesPaths(PipelineType::output));
 }
 
 auto AutoloadManager::getFilePath(const PipelineType& pipeline_type, QString device_name, QString device_route)
@@ -166,32 +166,42 @@ void AutoloadManager::load(const PipelineType& pipeline_type, const QString& dev
   const auto name = find(pipeline_type, device_name, device_route);
 
   if (name.empty()) {
-    QString fallback;
+    bool use_fallback = pipeline_type == PipelineType::input ? DbMain::inputAutoloadingUsesFallback()
+                                                             : DbMain::outputAutoloadingUsesFallback();
 
-    switch (pipeline_type) {
-      case PipelineType::input: {
-        fallback = db::Main::inputAutoloadingUsesFallback() ? db::Main::inputAutoloadingFallbackPreset() : "";
-        break;
-      }
-      case PipelineType::output: {
-        fallback = db::Main::outputAutoloadingUsesFallback() ? db::Main::outputAutoloadingFallbackPreset() : "";
-        break;
-      }
+    util::debug(
+        std::format("Could not find an autoload profile for the device {} and route {}. And the user did not enable "
+                    "the fallback preset. No autoload will be done.",
+                    device_name.toStdString(), device_route.toStdString()));
+
+    if (!use_fallback) {
+      return;
     }
 
-    if (!fallback.isEmpty()) {
-      util::debug(std::format("Autoloading fallback preset {} for device {}", fallback.toStdString(),
-                              device_name.toStdString()));
+    util::debug(std::format(
+        "Could not find an autoload profile for the device {} and route {}. We will try to load the fallback preset.",
+        device_name.toStdString(), device_route.toStdString()));
 
-      Q_EMIT loadFallbackPresetRequested(pipeline_type, fallback);
+    QString fallback = pipeline_type == PipelineType::input ? DbMain::inputAutoloadingFallbackPreset()
+                                                            : DbMain::outputAutoloadingFallbackPreset();
+
+    if (!fallback.isEmpty()) {
+      util::debug(
+          std::format("Autoload fallback preset {} for device {}", fallback.toStdString(), device_name.toStdString()));
+
+      Q_EMIT loadPresetRequested(pipeline_type, fallback);
 
       return;
     }
 
+    util::debug(std::format(
+        "The {} fallback preset name is empty. No preset will be autoloaded for the device {} and route {}",
+        pipeline_type == PipelineType::input ? "input" : "output", fallback.toStdString(), device_name.toStdString()));
+
     return;
   }
 
-  util::debug(std::format("Autoloading local preset {} for device {}", name, device_name.toStdString()));
+  util::debug(std::format("Autoload local preset {} for device {}", name, device_name.toStdString()));
 
   Q_EMIT loadPresetRequested(pipeline_type, QString::fromStdString(name));
 }
